# Advanced_delay

`advanced_delay` eklentisi deneyin daha önceden belirlenen ortalama süre ve buna ek olarak rastgele bir margin kadar ertelenmesini sağlar.

- *Duration* milisaniye olarak ortalama gecikme süresi.
- *Jitter* milisaniye olarak gecikmedeki varyasyon.
- *Jitter mode* jitterin nasıl hesaplandığınızı ayarlayabilmenizi sağlar:
	- *Standard deviation* Gaussian dağılımına uygun olarak belirlenen standart sapma doğrultusunda bir değişimleme sağlar.
	- *Uniform* tekdüze dağılıma uygun olarak bir değişimleme sağlar.
